@@ -93,6 +93,22 @@ static void brl_timeout_fn(struct event_context *event_ctx,
 	process_blocking_lock_queue();
 }
 
+/****************************************************************************
+ We need a version of timeval_min that treats zero timval as infinite.
+****************************************************************************/
+
+static struct timeval timeval_brl_min(const struct timeval *tv1,
+					const struct timeval *tv2)
+{
+	if (timeval_is_zero(tv1)) {
+		return *tv2;
+	}
+	if (timeval_is_zero(tv2)) {
+		return *tv1;
+	}
+	return timeval_min(tv1, tv2);
+}
+
 /****************************************************************************
  After a change to blocking_lock_queue, recalculate the timed_event for the
  next processing.
@@ -116,19 +132,13 @@ static bool recalc_brl_timeout(void)
 			 */
                         if (brl->blocking_pid == 0xFFFFFFFF) {
 				struct timeval psx_to = timeval_current_ofs(10, 0);
-				next_timeout = timeval_min(&next_timeout, &psx_to);
+				next_timeout = timeval_brl_min(&next_timeout, &psx_to);
                         }
 
 			continue;
 		}
 
-		if (timeval_is_zero(&next_timeout)) {
-			next_timeout = brl->expire_time;
-		}
-		else {
-			next_timeout = timeval_min(&next_timeout,
-						   &brl->expire_time);
-		}
+		next_timeout = timeval_brl_min(&next_timeout, &brl->expire_time);
 	}
 
 	if (timeval_is_zero(&next_timeout)) {
@@ -686,7 +696,6 @@ static void process_blocking_lock_queue(void)
 {
 	struct timeval tv_curr = timeval_current();
 	blocking_lock_record *blr, *next = NULL;
-	bool recalc_timeout = False;
 
 	/*
 	 * Go through the queue and see if we can get any of the locks.
@@ -736,7 +745,6 @@ static void process_blocking_lock_queue(void)
 			blocking_lock_reply_error(blr,NT_STATUS_ACCESS_DENIED);
 			DLIST_REMOVE(blocking_lock_queue, blr);
 			free_blocking_lock_record(blr);
-			recalc_timeout = True;
 			continue;
 		}
 
@@ -761,7 +769,6 @@ static void process_blocking_lock_queue(void)
 			blocking_lock_reply_error(blr,NT_STATUS_ACCESS_DENIED);
 			DLIST_REMOVE(blocking_lock_queue, blr);
 			free_blocking_lock_record(blr);
-			recalc_timeout = True;
 			change_to_root_user();
 			continue;
 		}
@@ -787,7 +794,6 @@ static void process_blocking_lock_queue(void)
 
 			DLIST_REMOVE(blocking_lock_queue, blr);
 			free_blocking_lock_record(blr);
-			recalc_timeout = True;
 			change_to_root_user();
 			continue;
 		}
@@ -823,13 +829,10 @@ static void process_blocking_lock_queue(void)
 			blocking_lock_reply_error(blr,NT_STATUS_FILE_LOCK_CONFLICT);
 			DLIST_REMOVE(blocking_lock_queue, blr);
 			free_blocking_lock_record(blr);
-			recalc_timeout = True;
 		}
 	}
 
-	if (recalc_timeout) {
-		recalc_brl_timeout();
-	}
+	recalc_brl_timeout();
 }
 
 /****************************************************************************
